@@ -1,6 +1,8 @@
 from typing import Optional
 
+from hexbytes import HexBytes
+
 
 class AccountAPI:
-    private_key: Optional[str]
+    private_key: Optional[HexBytes]
     address: Optional[str]
